@@ -48,7 +48,7 @@ plan:
 - make it show faster. -done
 - add option --only-daemon to only start the daemon without showing the GUI -done
 - right-click on center opens a general config dialog. -todo
-- a general config dialog. -todo
+- a general config dialog. -done
 - first run of new version shows image as usage guide. -todo
 """
 __ideas__ = """
@@ -99,7 +99,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.5.3"
+__version__ = "0.6.0"
 appName = "pyRad"
 
 ### Commandline handling ###
@@ -118,6 +118,10 @@ def importRad():
     from rad import Rad
     return Rad
 
+def programIcon():
+    from rad import PROGRAM_ICON
+    return PROGRAM_ICON
+
 # We also do the other imports in functions to facilitate profiling. 
 # Then commandline arguments and handling
 from PyKDE4.kdecore import KCmdLineArgs, KCmdLineOptions
@@ -126,7 +130,7 @@ from PyKDE4.kdecore import KCmdLineArgs, KCmdLineOptions
 from PyKDE4.kdecore import ki18n, KAboutData
 
 # KApplication for basics
-from PyKDE4.kdeui import KUniqueApplication
+from PyKDE4.kdeui import KUniqueApplication, KStatusNotifierItem #, KSessionManager # for handling sessions by hand, should quit not work.
 
 # SIGNALs and SLOTs for a clean shutdown. 
 from PyQt4.QtCore import SIGNAL, SLOT
@@ -145,8 +149,19 @@ class KUniqueCaller(KUniqueApplication):
         # And get and show the GUI
         Rad = importRad()
         self.rad = Rad()
+        # and a tray icon
+        self.statusnotifier = KStatusNotifierItem(self.rad)
+        self.statusnotifier.setCategory(0) # 0 = ApplicationStatus
+        self.statusnotifier.setIconByName(programIcon())
+        
         self.connect(self, SIGNAL("shutDown()"), self.close)
         self.connect(self, SIGNAL("shutDown()"), self.quit)
+        self.connect(self.rad, SIGNAL("queryClose()"), self.close)
+
+    def quit(self):
+        """Quit the program: close the rad, then quit."""
+        self.close()
+        super(KUniqueCaller, self).quit()
 
     def close(self):
         """Slot for closing the rad."""
@@ -156,11 +171,11 @@ class KUniqueCaller(KUniqueApplication):
         """Get a new instance -> in reality only check if there's already an instance and tell the GUI to run."""
         # if we get the quit arg ("pyrad.py --quit"), we close and shutdown
         args = KCmdLineArgs.parsedArgs()
-        if args.isSet("quit"):
+        if args.isSet("quit") or args.isSet("kill"):
             self.rad.close()
             self.quit()
             return 0
-        elif args.isSet("daemon"): 
+        elif args.isSet("daemon") or args.isSet("start"): 
             ret = super(KUniqueCaller, self).newInstance()
             return ret
         self.rad.setup()
@@ -202,7 +217,9 @@ def initKApp():
     # Add an option to quit the app
     opts = KCmdLineOptions()
     opts.add("quit", ki18n("Shutdown the background program"))
+    opts.add("kill", ki18n("Shutdown the background program"))
     opts.add("daemon", ki18n("Start the background program without showing the GUI "))
+    opts.add("start", ki18n("Start the background program without showing the GUI "))
     KCmdLineArgs.addCmdLineOptions(opts)
     # Then do basic initializing
     app = KUniqueCaller()
@@ -224,4 +241,8 @@ def run():
 ### Self Test == Run the Program ###
 
 if __name__ == "__main__":
+    # CherryPy for finding the memory leak 
+    # import cherrypy
+    # from dowser import *
+    # cherrypy.quickstart(Root())
     exit_(run())
